.. _findsat_mrt:

************************************
MRT-based Satellite Trails Detection
************************************

.. automodapi:: acstools.findsat_mrt
    :no-heading:
    :no-inheritance-diagram:

Helper Functions
================

.. automodapi:: acstools.utils_findsat_mrt
    :no-heading:
    :no-inheritance-diagram:
